==> 0.0.2.tar.gz: lib/services/session.dart <==
import 'dart:convert';
import 'dart:io';

import 'package:dio/dio.dart';
import 'package:location/location.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:permission_handler/permission_handler.dart' as p;

import 'package:bizdoc/models/notifications.dart';
import 'package:bizdoc/models/profile.dart';
import 'base.dart';

class Session extends Service {
  late Profile _profile;

  Profile get profile => _profile;

  Future<String?> company() async {
    final preferences = await SharedPreferences.getInstance();
    return preferences.getString('company');
  }

  Future<bool> _restore() async {
    try {
      final file = File('bizdoc.json');
      final json = await file.readAsString();
      _profile = Profile.fromJson(jsonDecode(json));
      return true;
    } catch (e) {
      print(e);
    }
    return false;
  }

  /// post sign in
  void _save(response) async {
    try {
      await p.Permission.storage.request();
      final file = File('bizdoc.json');
      await file.writeAsString(jsonEncode(response));
    } catch (e) {
      //rethrow;
    }
  }

  Future refresh() async {
    try {
      final response = await dio.get('/account/refresh');
      _profile = Profile.fromJson(response.data);
      _save(response.data);
    } on DioError catch (e) {
      if (e.response != null && e.response!.statusCode == 401) {
        throw UnauthorizedError();
      }
      rethrow;
    }
  }

  Future registerDevice(String token, String device) async {
    await dio.post('/account/registerDevice',
        data: {'type': device, 'token': token});
    final prefs = await SharedPreferences.getInstance();
    prefs.setString('connectionId', token);
    dio.options.headers['connection-id'] = token;
  }

  Future availabilityMode(AvailabilityMode mode) async {
    await dio.post('/account/available?mode=$mode');
  }

  Future online(bool val) async {
    await dio.post('/account/online/?online=$val');
  }

  Future<LocationData?> geoLocation() async {
    Location location = Location();

    bool serviceEnabled;
    PermissionStatus permissionGranted;
    LocationData locationData;

    serviceEnabled = await location.serviceEnabled();
    if (!serviceEnabled) {
      serviceEnabled = await location.requestService();
      if (!serviceEnabled) {
        return null;
      }
    }

    permissionGranted = await location.hasPermission();
    if (permissionGranted == PermissionStatus.denied) {
      permissionGranted = await location.requestPermission();
      if (permissionGranted != PermissionStatus.granted) {
        return null;
      }
    }

    locationData = await location.getLocation();
    return locationData;
  }

  Future seenNotifications() async {
    await dio.put('/account/notificationsview');
    _profile.notificationsCount = 0;
  }

  Future seenMessages() async {
    await dio.put('/account/inboxview');
    _profile.inboxCount = 0;
  }

  Future<bool> hasServerUri() async {
    final prefs = await SharedPreferences.getInstance();
    return prefs.containsKey('baseUri');
  }

  setup(String serverUri) async {
    serverUri = serverUri.trim();
    if (!serverUri.startsWith('http')) serverUri = 'https://' + serverUri;
    if (serverUri.endsWith('/')) {
      serverUri = serverUri.substring(0, serverUri.lastIndexOf('/'));
    }
    final response =
        await dio.get('$serverUri/api/account/ping', options: Options());
    if (!(response.data as Map).containsKey('bizDoc')) throw '';
    final prefs = await SharedPreferences.getInstance();
    prefs.setString('baseUri', serverUri);
    dio.options.baseUrl = serverUri + '/api';
  }

  Future<Iterable<NotificationBase>> notifications({DateTime? before}) async {
    final Map<String, dynamic> queryParameters = {};
    if (before != null) queryParameters['before'] = before.toIso8601String();
    final response =
        await dio.get('/notifications', queryParameters: queryParameters);
    return response.data.map((e) => NotificationBase.construct(e));
  }

  Future<dynamic> dashboard(String name) async {
    final response = await dio.get('/dashboard/$name');
    return response.data;
  }
}

enum AvailabilityMode { offline, online, outOfOffice, vacation }

var session = Session();

==> 0.0.3.tar.gz: lib/services/session.dart <==
import 'dart:convert';
import 'dart:io';

import 'package:dio/dio.dart';
import 'package:location/location.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:permission_handler/permission_handler.dart' as p;

import 'package:bizdoc/models/notifications.dart';
import 'package:bizdoc/models/profile.dart';
import 'base.dart';

class Session extends Service {
  late Profile _profile;

  Profile get profile => _profile;

  Future<String?> company() async {
    final preferences = await SharedPreferences.getInstance();
    return preferences.getString('company');
  }

  Future<bool> _restore() async {
    try {
      final file = File('bizdoc.json');
      final json = await file.readAsString();
      _profile = Profile.fromJson(jsonDecode(json));
      return true;
    } catch (e) {
      print(e);
    }
    return false;
  }

  /// post sign in
  void _save(response) async {
    try {
      await p.Permission.storage.request();
      final file = File('bizdoc.json');
      await file.writeAsString(jsonEncode(response));
    } catch (e) {
      //rethrow;
    }
  }

  Future refresh() async {
    try {
      final response = await dio.get('/account/refresh');
      _profile = Profile.fromJson(response.data);
      _save(response.data);
    } on DioError catch (e) {
      if (e.response != null && e.response!.statusCode == 401) {
        throw UnauthorizedError();
      }
      rethrow;
    }
  }

  Future registerDevice(String token, String device) async {
    await dio.post('/account/registerDevice',
        data: {'type': device, 'token': token});
    final preferences = await SharedPreferences.getInstance();
    preferences.setString('connectionId', token);
    dio.options.headers['connection-id'] = token;
  }

  Future availabilityMode(AvailabilityMode mode) async {
    await dio.post('/account/available?mode=$mode');
  }

  Future online(bool val) async {
    await dio.post('/account/online/?online=$val');
  }

  Future<LocationData?> geoLocation() async {
    Location location = Location();

    bool serviceEnabled;
    PermissionStatus permissionGranted;
    LocationData locationData;

    serviceEnabled = await location.serviceEnabled();
    if (!serviceEnabled) {
      serviceEnabled = await location.requestService();
      if (!serviceEnabled) {
        return null;
      }
    }

    permissionGranted = await location.hasPermission();
    if (permissionGranted == PermissionStatus.denied) {
      permissionGranted = await location.requestPermission();
      if (permissionGranted != PermissionStatus.granted) {
        return null;
      }
    }

    locationData = await location.getLocation();
    return locationData;
  }

  Future seenNotifications() async {
    await dio.put('/account/notificationsView');
    _profile.notificationsCount = 0;
  }

  Future seenMessages() async {
    await dio.put('/account/inboxView');
    _profile.inboxCount = 0;
  }

  Future<bool> hasServerUri() async {
    final preferences = await SharedPreferences.getInstance();
    return preferences.containsKey('baseUri');
  }

  setup(String serverUri) async {
    serverUri = serverUri.trim();
    if (!serverUri.startsWith('http')) serverUri = 'https://' + serverUri;
    if (serverUri.endsWith('/')) {
      serverUri = serverUri.substring(0, serverUri.lastIndexOf('/'));
    }
    final response =
        await dio.get('$serverUri/api/account/ping', options: Options());
    if (!(response.data as Map).containsKey('bizDoc')) throw '';
    final preferences = await SharedPreferences.getInstance();
    preferences.setString('baseUri', serverUri);
    dio.options.baseUrl = serverUri + '/api';
  }

  Future<Iterable<NotificationBase>> notifications({DateTime? before}) async {
    final Map<String, dynamic> queryParameters = {};
    if (before != null) queryParameters['before'] = before.toIso8601String();
    final response =
        await dio.get('/notifications', queryParameters: queryParameters);
    return response.data.map((e) => NotificationBase.construct(e));
  }

  Future<dynamic> dashboard(String name) async {
    final response = await dio.get('/dashboard/$name');
    return response.data;
  }
}

enum AvailabilityMode { offline, online, outOfOffice, vacation }

var session = Session();
